.. _index-page:

.. Omit README table of contents; TODO: Can markdown anchors be converted to rST refs?
.. mdinclude:: ../README.md
    :end-line: 25

.. mdinclude:: ../README.md
    :start-line: 31


Contents
========

.. toctree::
    :maxdepth: 2

    user_guide
    examples
    endpoints
    reference
    contributing
    contributors
    history
